--[[
	Description: Configuration used by DataMiner
	Copyright (C) 2014, 2015 Linuz@Proudmore.Eu
    This program is free software; you can redistribute it and/or modify it under the terms of the
	GNU General Public License as published by the Free Software Foundation; either version 2 of the License,
	or (at your option) any later version.
    This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
	without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
	See the GNU General Public License for more details.
    You should have received a copy of the GNU General Public License along with this program;
	if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
--]]

-- Library references
local L = LibStub("AceLocale-3.0"):GetLocale("DataMiner", true)
local AceConfigDialog = LibStub("AceConfigDialog-3.0")
local AceConfigRegistry = LibStub("AceConfigRegistry-3.0")
local AceConfig = LibStub("AceConfig-3.0")

-- Variables
local Addon = "DataMiner"						
collect = false				--enable dm, needed by DMTitan for RightClickMenu

dm_herbs, dm_ore = {}, {};
dm_log, logsize, logg = {}, 50, true;             -- max lines in log
dm_sc = { -- This list is only in use, if no list is loaded via SavedVariables as example
	{ ["aKey"] = "KRAUT",    ["aCommand"] = "/dm table herbs" },			-- [1]
	{ ["aKey"] = "MINERALE", ["aCommand"] = "/dm table ore" },				-- [2]
	{ ["aKey"] = "ULDUM",    ["aCommand"] = "/dm view zone Uldum" },		-- [3]
	{ ["aKey"] = "SBL",      ["aCommand"] = "/dm view item Silberblatt" },	-- [4]
	{ ["aKey"] = "TITAN",    ["aCommand"] = "/titan gui control" },         -- [5]
}

dm_exclude = { -- This list is only in use, if no list is loaded via SavedVariables
	-- If the item is here with aExclude=true, we are not interested in it
	{ ["aID"] = 22573, ["aExclude"] = true }, -- [1]--Earth Particle
	{ ["aID"] = 22574, ["aExclude"] = true }, -- [2]--Fire Particle
	{ ["aID"] = 22575, ["aExclude"] = true }, -- [3]--Living Particle
	{ ["aID"] = 22788, ["aExclude"] = true }, -- [4]--Flamecap
	{ ["aID"] = 22795, ["aExclude"] = true }, -- [5]--Devilsflower
	{ ["aID"] = 24245, ["aExclude"] = true }, -- [6]--Gluecap
	{ ["aID"] = 24401, ["aExclude"] = true }, -- [7]--Unknown Plantparts
	{ ["aID"] = 36908, ["aExclude"] = true }, -- [8]--Frozen Lotus
	{ ["aID"] = 37701, ["aExclude"] = true }, -- [9]--Crystallized Earth
	{ ["aID"] = 37702, ["aExclude"] = true }, -- [10]--Crystallized Fire
	{ ["aID"] = 37704, ["aExclude"] = true }, -- [11]--Crystallized Living
	{ ["aID"] = 37705, ["aExclude"] = true }, -- [12]--Crystallized Water
	{ ["aID"] = 52326, ["aExclude"] = true }, -- [13]--Volatile Water
	{ ["aID"] = 52329, ["aExclude"] = true }, -- [14]--Volatile Living
	{ ["aID"] = 63122, ["aExclude"] = true }, -- [15]--Livinggiving Seed
}

local excludes = {
	name = L["Excludes"],
	type = "group",
	args = {}
}

local sc = {  -- the struct will be completed in CreateSC()
	order = 1,
	name = L["Chat_Shortcuts"],
	type = "group", inline = false,
	args = {}
}

------------
-- Config --
------------

function GetVersion()
	return tostring(GetAddOnMetadata("TitanDataMiner", "Version"))
end

function GetAuthor()
	return GetAddOnMetadata("TitanDataMiner", "Author")
end

function GetCategory()
	return GetAddOnMetadata("TitanDataMiner", "X-Category")
end

local function GetLocalizations()
	return GetAddOnMetadata("TitanDataMiner", "X-Localizations")
end

local info = {
	name = Addon,
	type = "group",
	args = {
		cfg_info_desc = {
			order = 1,
			type = "description",
			name = L["Short_Addon_Desc"].."\n\n",
			cmdHidden = true
		},
		cfg_info = {
			order = 2,
			name = "Info",
			type = "group", inline = true,
			args = {
				cfg_ver = {
					order = 1,
					type = "description",
					name = COL_GOLD.."Version"..": "..COL_GREEN..GetVersion(),
					cmdHidden = true
				},
				cfg_author = {
					order = 2,
					type = "description",
					name = COL_GOLD..L["Author"]..": "..COL_ORANGE2..GetAuthor(),
					cmdHidden = true
				},
				cfg_cat = {
					order = 3,
					type = "description",
					name = COL_GOLD..L["Category"]..": "..COL_WHITE..GetCategory(),
					cmdHidden = true
				},
				cfg_localizations = {
					order = 4,
					type = "description",
					name = COL_GOLD..L["Localizations"]..": "..COL_WHITE..GetLocalizations(),
					cmdHidden = true
				},
				--cfg_l = { -- under construction
					--order =	5, name = img,
					--type = "execute", --width = "fill",
					--icon=AddOns\TitanDataMiner\bitmap\us.png
					--func = function() table.insert( dm_sc, {aKey = inc(#dm_sc), aCommand = ""} ) CreateSC() end,
					--cmdHidden = true
				--},
				cfg_license = {
					order = 10,
					type = "description",
					name = COL_GOLD..L["License"]..": "..COL_WHITE.."GPLv2(see license.txt)",
					cmdHidden = true
				},
			}
		},
		cfg_space1 = {
			order = 3,
			type = "description",
			name = "\n",
			cmdHidden = true
		},
		cfg_log = {   -- under construction
			order = 4,
			name = L["Loging_Settings"],
			type = "group", inline = true,
			args = {
				cfg_toggle_log = {
					order = 1, name = L["Loging"],
					type = "toggle", width = "normal",
					get = function() return logg end,
					set = function( _,value ) logg = value end,
					cmdHidden = true
				},
				cfg_logsize = {
					order =	2, name = L["Log_size"],
					type = "input", width = "half",
					get = function() return tostring(logsize) end,
					set = function( _,value ) logsize = tonumber(value) end,
					disabled = function() return not logg end,
					cmdHidden = true
				},
				cfg_current_log = {
					order =	5, name = L["Delete_log"],
					type = "input", width = "full",
					get = function()
						local txt = ""
						for idx, line in ipairs(dm_log) do txt = txt..line.aLog.."\n" end
						return txt
					end,
					multiline = 14,
					dialogControl = "TextBox",
					cmdHidden = true
				},
				cfg_del = {
					order =	6, name = L["Delete"],
					type = "execute", width = "normal",
					func = function() Table_reset(dm_log) DM_Log_Msg(108) end,
					cmdHidden = true
				},
			}
		},	
	}
}

local function CreateEX()
	local args = excludes.args
	wipe(args)
	
	args["about_ex"] = {
		order = 0,
		type = "description",
		name = L["Excludes_Desc"],
		cmdHidden = true
	}
	for idx, value in pairs(dm_exclude) do
		args[tostring(idx)] = {
			order = idx,
			type = "group", inline = false,
			name = GetItemInfo(value.aID) or tostring(value.aID), -- left group
			args = {
				header = {
					order =	0, name = GetItemInfo(value.aID) or tostring(value.aID),
					type = "header", width = "full"
				},
				id = {
					order =	1, name = "Item-ID",
					type = "input", width = "full",
					get = function() return tostring(value.aID) end,
					set = function( _,value ) dm_exclude[idx].aID = value CreateEX() end,
					cmdHidden = true
				},
				exclude = {
					order = 2, name = "Exclude",
					type = "toggle", width = "half",
					get = function() return value.aExclude end,
					set = function( _,value ) dm_exclude[idx].aExclude = value CreateEX() end,
					cmdHidden = true
				},
				add = {
					order =	3, name = L["Add"],
					type = "execute", width = "normal",
					func = function() table.insert( dm_exclude, {aID = 00000, aExclude = false} ) CreateEX() end,
					cmdHidden = true
				},
				delete = { 
					order =	4, name = L["Delete"],
					type = "execute", width = "half",
					func = function() table.remove( dm_exclude, idx ) CreateEX() end,
					cmdHidden = true
				}
			},
		}
	end
end

local function CreateSC()
	local args = sc.args
	wipe(args)
	
	args["about"] = {
		order = 0,
		type = "description",
		name = L["Shortcut_Desc"],
		cmdHidden = true
	}
	for idx, value in pairs(dm_sc) do
		args[tostring(idx)] = {
			type = "group", inline = false,
			name = value.aKey, -- left group
			order = idx,
			args = {
				key = {
					order =	1, name = L["Key"],
					type = "input", width = "full",
					get = function() return dm_sc[idx].aKey end,
					set = function( _,value ) dm_sc[idx].aKey = value:upper() CreateSC() end,
					cmdHidden = true
				},
				command = {
					order =	2, name = L["Command"],
					type = "input", width = "full",
					get = function() return dm_sc[idx].aCommand end,
					set = function( _,value ) dm_sc[idx].aCommand = value end,
					cmdHidden = true
				},
				add = {
					order =	3, name = L["Add"],
					type = "execute", width = "fill",
					func = function() table.insert( dm_sc, {aKey = inc(#dm_sc), aCommand = ""} ) CreateSC() end,
					cmdHidden = true
				},
				delete = { 
					order =	4, name = L["Delete"],
					type = "execute", width = "fill",
					func = function() table.remove( dm_sc, tonumber(idx) ) CreateSC() end,
					cmdHidden = true
				}
			},
		}
	end
end

function SetupConfig()
	AceConfig:RegisterOptionsTable( Addon, info )
	AceConfigDialog:AddToBlizOptions( Addon, Addon )
	--
	CreateEX()
	AceConfig:RegisterOptionsTable( L["Excludes"], excludes )
	AceConfigDialog:AddToBlizOptions( L["Excludes"], L["Excludes"], Addon )
	--
	CreateSC()
	AceConfig:RegisterOptionsTable( L["Chat_Shortcuts"], sc )
	AceConfigDialog:AddToBlizOptions( L["Chat_Shortcuts"], L["Chat_Shortcuts"], Addon )
end
