--[[
	Description: LDB functions used by DataMiner
	Copyright (C) 2014, 2015 Linuz@Proudmore.Eu
    This program is free software; you can redistribute it and/or modify it under the terms of the
	GNU General Public License as published by the Free Software Foundation; either version 2 of the License,
	or (at your option) any later version.
    This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
	without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
	See the GNU General Public License for more details.
    You should have received a copy of the GNU General Public License along with this program;
	if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
--]]

-- Library references
local L = LibStub("AceLocale-3.0"):GetLocale("DataMiner", true)
local CallbackHandler = LibStub("CallbackHandler-1.0")
local LibDataBroker = LibStub("LibDataBroker-1.1")

local Addon = "DataMiner"
dm_ldb = { id = "DM", addon = Addon, button_label = Addon, menu_text = Addon }
local dmldb = dm_ldb

function LDB_SetTitle( vmode, s )
	if ( vmode == 0 ) then -- We reset the title
		dmldb.tooltip_header = GetHexColoredText( Addon, COL_WHITE )
							   ..GetHexColoredText( "\rby"..GetAuthor(), COL_GREEN )
	elseif ( vmode == 7 ) then
		dmldb.tooltip_header = GetHexColoredText( L["Current_Zone_Weekday_Time"], COL_WHITE )
	elseif( vmode == 8 ) then
		dmldb.tooltip_header = GetHexColoredText( L["Item"]..": "..WordUpper(s), COL_WHITE )
	elseif( vmode == 17 ) then
		dmldb.tooltip_header = GetHexColoredText( L["Zone"]..": "..WordUpper(s), COL_WHITE )
	end
end

function LDB_GetTooltipText()
    return DM_GetTooltipText()
end

function dmldb.LDB_OnTooltipShow(tooltip)
	-- Add title
	tooltip:AddLine(dmldb.tooltip_header)
	local text = LDB_GetTooltipText()
	-- Add a linefeed to the end if not already there
	if ( string.sub(text, -1, -1) ~= "\n" ) then
		text = text.."\n";
	end
	for text1, text2 in string.gmatch(text, "([^\t\n]*)\t?([^\t\n]*)\n") do
		if ( text2 ~= "" ) then
			tooltip:AddDoubleLine(text1, text2);
		elseif ( text1 ~= "" ) then
			tooltip:AddLine(text1);
		else
			tooltip:AddLine("\n");
		end			
	end
end

function dmldb:LDB_Init(f)
	-- Reduce the chance of functions and variables colliding with another addon.
	dmldb.tooltip_header = GetHexColoredText(Addon, COL_WHITE)..GetHexColoredText("\rby"..GetAuthor(), COL_GREEN)
	dmldb.version = GetVersion()
	dmldb.author = GetAuthor()
	dmldb.category = GetCategory()
	-- Set the LDB frame needed for the other LDB routines
	dmldb.LDB_frame = CreateFrame("Frame")
	dmldb.LDB_frame.obj = {}
	dmldb.LDB_frame.obj = LibStub("LibDataBroker-1.1"):NewDataObject(dmldb.id, {
		type = "data source", -- "data source" left side plugin to show info
							  -- "launcher" right side plugin to launch another window
		icon = "Interface\\Icons\\Trade_herbalism.blp",
		label = Addon,  -- button text.
		text  = Addon,  -- ChocolateBar use this as button text
		OnClick = function(self, mousebutton)
			if ( mousebutton == "RightButton" ) then print("LDB right mouse button") end
			if ( mousebutton == "LeftButton" ) then ToggleDataMining(f) end
		end,
		OnTooltipShow = function(tooltip) dmldb.LDB_OnTooltipShow(tooltip) end,
	})
end

function dmldb.Button_OnLoad(f)
	dmldb:LDB_Init(f)
end
