--[[
	Description: Titan functions used by DataMiner
	Copyright (C) 2014, 2015 Linuz@Proudmore.Eu
    This program is free software; you can redistribute it and/or modify it under the terms of the
	GNU General Public License as published by the Free Software Foundation; either version 2 of the License,
	or (at your option) any later version.
    This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
	without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
	See the GNU General Public License for more details.
    You should have received a copy of the GNU General Public License along with this program;
	if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
--]]

-- Library references
local L = LibStub("AceLocale-3.0"):GetLocale("DataMiner", true)

local Addon = "DataMiner"

-- Init the right-click menue
function TitanPanelRightClickMenu_PrepareDMMenu()
	local function addSubMenu( txt )
		local info = UIDropDownMenu_CreateInfo();
		info.text = txt;
		info.hasArrow = true;    	-- as submenue
		info.notCheckable = true; 	-- text only
		info.notClickable = true;
		info.keepShownOnClick = true;
		UIDropDownMenu_AddButton(info, UIDROPDOWNMENU_MENU_LEVEL);
	end
	local function addMenuItem( txt, func, disabled, checked, tooltip, close_tooltip )
		local info = UIDropDownMenu_CreateInfo();
		info.text = txt;
		info.func = func;           -- this will be processed, when we click
		info.isNotRadio = true;     -- use check mark
		info.checked = checked;  	-- check the button if true or function returns true
		if (disabled) then info.disabled = disabled end
		if (tooltip) then info.tooltipTitle = tooltip
		else info.tooltipTitle = txt end
		if ( not close_tooltip ) then info.keepShownOnClick = true end
		UIDropDownMenu_AddButton(info, UIDROPDOWNMENU_MENU_LEVEL);
	end
		
	if ( UIDROPDOWNMENU_MENU_LEVEL == 1 ) then
		TitanPanelRightClickMenu_AddTitle("DataMiner Settings");
				
		addMenuItem( L["Toggle_datamining"], function() ToggleDataMining(self) end,
					 not HasProfession(PROF_HERBALISM,false) and not HasProfession(PROF_MINING,false),
					 collect);
		addMenuItem( L["Toggle_loging"], function() DM_Toggle_Log() end, false, logg );
		addSubMenu( L["Excludes"] );
		addSubMenu( L["Log_size"] );
	end	
	
	if ( UIDROPDOWNMENU_MENU_LEVEL == 2 ) then
		if( UIDROPDOWNMENU_MENU_VALUE == L["Excludes"]) then
			for idx, line in ipairs(dm_exclude) do
				addMenuItem( GetItemInfo(line.aID),
							 function() dm_exclude[idx].aExclude = Toggle(dm_exclude[idx].aExclude) end,
							 false, line.aExclude, "ID = "..line.aID, false)
			end
		elseif( UIDROPDOWNMENU_MENU_VALUE == L["Log_size"]) then
			addMenuItem( "50", function() logsize = 50 end, nil, logsize==50, L["Log_size"], true)
			addMenuItem( "100", function() logsize = 100 end, nil, logsize==100, L["Log_size"], true)
		end
	end
end

function TitanPanelDMButton_OnClick(self, mousebutton)
	if (mousebutton == "RightButton") then
		TitanPanelRightClickMenu_PrepareDMMenu()
	end
	TitanPanelButton_OnClick(self, mousebutton)
end

function Titan_SetTitle( vmode, s )
	if ( vmode == 0 ) then 	-- We reset the title
		TitanPlugins["DM"].tooltipTitle = Addon..GetHexColoredText("\rby"..GetAuthor(), COL_GREEN)
	elseif ( vmode == 7 ) then
		TitanPlugins["DM"].tooltipTitle = L["Current_Zone_Weekday_Time"]
	elseif( vmode == 8 ) then
		TitanPlugins["DM"].tooltipTitle = L["Item"]..": "..WordUpper(s)
	elseif( vmode == 17 ) then
		TitanPlugins["DM"].tooltipTitle = L["Item"]..": "..WordUpper(s)
	end
end

function TitanPanelDMButton_GetTooltipText()
	return DM_GetTooltipText()
end

function TitanPanelDMButton_GetButtonText()
	return "DataMiner"
end

-- Register with Titan as NATIVE Addon
function TitanPanelDMButton_OnLoad(self)
	self:SetFrameStrata("FULLSCREEN")
	self.registry = {
		id = "DM", -- If we change that id we have also change all function names with *DM* in it
		menuText = "Titan |c0070DE5fDataMiner|r",
		buttonTextFunction = "TitanPanelDMButton_GetButtonText",
		tooltipTitle = Addon..GetHexColoredText("\rby"..GetAuthor(), COL_GREEN),
		tooltipTextFunction = "TitanPanelDMButton_GetTooltipText",
		frequency = 1,
		icon = "Interface\\Icons\\Trade_herbalism.blp",
		iconWidth = 16,
		category = "Profession",
		controlVariables = {
			ShowIcon = true,
			ShowLabelText = true,
			ShowRegularText = false,
			ShowColoredText = true,
			DisplayOnRightSide = false
		},
		savedVariables = {
			ShowIcon = 1,
			ShowLabelText = 1,
			ShowColoredText = 1,
		}
	}
end
